// Temporary proxy for letting existing code find bundled NL include files
// without changing it

#ifndef GEOGRAM_NL
#define GEOGRAM_NL

#include <geogram/third_party/OpenNL/nl.h>

#endif
